#
# spec file for package lxmusic
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with gtk3

Name:           lxmusic
Version:        0.4.7
Release:        1.1
Summary:        Lightweight Audio Player
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            http://www.lxde.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  docbook-utils
BuildRequires:  fdupes
%if %{with gtk3}
BuildRequires:  gtk3-devel
%else
BuildRequires:  gtk2-devel
%endif
BuildRequires:  intltool
BuildRequires:  libnotify-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  xmms2-devel >= 0.7
Requires:       xmms2
Recommends:     %{name}-lang
Recommends:     xmms2-plugin-restricted
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LXMusic is just a lightweight audio player,
that uses xmms2 as back-end.

%lang_package

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%configure \
%if %{with gtk3}
  --enable-gtk3
%endif

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%find_lang %{name}
%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root,0755)
%doc COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/lxmusic
%{_datadir}/lxmusic/*.ui.glade
%{_datadir}/pixmaps/lxmusic.png
%{_mandir}/man1/lxmusic.1.gz

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Wed Aug  3 2016 antoine.belvire@laposte.net
- Update to 0.4.7:
  * Update translations
  * Add option to compile with GTK3
- Add xmms2-plugin-restricted as recommended package (boo#980920)
- Add bcond to build with or without GTK3 (not used by default)
* Sat Sep  6 2014 trcs@gmx.com
- new upstream version 0.4.6
  * Add manual page lxmusic.1 to install
  * Replace g_format_size_for_display() with glib >= 2.30 as
    deprecated
  * Fixed few invalid casts and deprecated gdk_pixbuf_unref() calls
  * Properly return NULL from lxmusic_do_notify_prepare() if no
    libnotify available
  * [SF#252]Destroy any dialog windows on exit
  * Avoid duplicate gtk_widget_destroy() on main window - it
    crashes on exit
  * [SF#316]update_track() should not use GtkTreeIter - it may
    become invalid ATM
  * [SF#335]Safeguard against NULL passed to guess_title_from_url()
  * Safeguards for xmmsv_get_*() -- we should use it only if
    xmmsv_dict_get() was success
  * Use macro AM_MAINTAINER_MODE correct way - with ([enable])
  * Fix $(desktop_in_files) missing in distro tarball
  * Fix crash if "id" is not available
  * [SF#506]Correct Name in the desktop entry file, it should
    differ from GenericName
  * Add .gitignore file
  * autogen.sh: update check for automake version and remove never
    used libtoolize call
  * Add compatibility with libnotify >= 0.7.0
  * Generate po/LINGUAS file on the fly
  * Use correct parameters for AC_INIT and AM_INIT_AUTOMAKE macros
  * Rename configure.in into configure.ac
  * New and updated translations
- removed lxmusic-0.4.4-libnotify0.7.0.patch
  * fixed upstream
- spec file cleanup
* Fri Jun 22 2012 mvyskocil@opensuse.org
- update to 0.4.5
- drop lxmusic-0.4.4-no-gcc-warnings.patch
- drop lxmusic-0.4.4-wrong-encoding-it-po.patch
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Sep 22 2011 andrea.turrini@gmail.com
- fixed typos in lxmusic.spec
* Thu May  5 2011 andrea@opensuse.org
- added lxmusic-0.4.4-libnotify0.7.0.patch to allow build with
  libnotify >= 0.7.0 because of API changes
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Thu May 13 2010 andrea@opensuse.org
- added xmms2 and an explicit dependecy fix bnc#605537
* Mon Apr 19 2010 andrea@opensuse.org
- added lxmusic-0.4.4-wrong-encoding-it-po.patch to fix a wrong
  char encoding into it.po
* Fri Apr 16 2010 andrea@opensuse.org
- split -lang package
* Tue Apr 13 2010 andrea@opensuse.org
- new upstream version 0.4.4
- added lxmusic-0.4.4-no-gcc-warnings.patch to fix gcc warnings
* Tue Apr  6 2010 andrea@opensuse.org
- removed unsopported locales
* Mon Mar  1 2010 andrea@opensuse.org
- new upstream version 0.4.3
- fix few bugs
- port to new xmms2 0.7 API changes
* Tue Dec 29 2009 andrea@opensuse.org
- new upstream version 0.4.2
- fix all gcc compilation warnings: LXMusic can be
  compiled using CFLAGS "-Wall -Werror"
- on_playlist_content_received: request medialib info for whole
  playlist at once instead of requesting and updating each track successive:
  This improves speed for loading whole playlist a lot because we get
  rid of a lot of context switches between lxmusic and xmms2d.
- on_playlist_content_received: use gtk_list_store_insert_with_values:
  This single call is is more efficient on large playlists than calling
  gtk_list_store_append and gtk_list_store_set (which emits also
  row_changed and rows_reordered signals).
- fix memory leak: prev. playlist model/filter not freed when switching
  playlist
- get rid of xmmsv_propdict_to_dict and thus of a lot of
  intermediate propdicts allocated on the heap:
  According to Google perftools this reduces heap usage from 24MB to 2MB
  when loading a 4000-track play-list.
- Translation updates
* Sat Dec 19 2009 andrea@opensuse.org
- new upstream version 0.4.1
- fixed bug #2902106 (fedora bugzilla)
  Crash of LXMusic when emptying large play lists
* Fri Aug 21 2009 andrea@opensuse.org
- new upstream version
- removed no more useful gcc patch
* Tue Jul 14 2009 andrea@opensuse.org
- fixed gcc checks issues
* Wed Jul  8 2009 andrea@opensuse.org
- New upstream version 0.3.0
* Fri May 22 2009 andrea@opensuse.org
- New package
